@@ -5,6 +5,7 @@ import functools
 from typing import Any, List, Optional
 from dacite import from_dict, config
 from requests import Response, Session
+from urllib.parse import quote as sanitize_param
 
 from coiote.auth import Authenticator
 from coiote.v3.model.devices import parse_psk, DtlsPreSharedKey
@@ -97,3 +98,10 @@ def api_call(response_format: Optional[Any] = None):
         return wrap_with_response_handle
 
     return decorator_deserialize
+
+
+def sanitize_request_param(param: Optional[str]) -> Optional[str]:
+    if param is None:
+        return None
+    else:
+        return sanitize_param(param, safe='')
