@@ -1,8 +1,7 @@
 from datetime import datetime
 from typing import Optional
-from urllib.parse import quote as sanitize_param
 
-from coiote.utils import ApiEndpoint, api_call, ISO_INSTANT_FORMAT
+from coiote.utils import ApiEndpoint, api_call, ISO_INSTANT_FORMAT, sanitize_request_param
 from coiote.v3.model.device_monitoring import MonitoringStatus, MonitoringDataResponse
 
 
@@ -19,7 +18,7 @@ class DeviceMonitoring(ApiEndpoint):
     @api_call(MonitoringDataResponse)
     def get_data_batch(self, device_id: str, lwm2m_url: str, start_time: datetime, end_time: Optional[datetime],
                        limit=2048) -> MonitoringDataResponse:
-        safe_lwm2m_url = sanitize_param(lwm2m_url, safe='')
+        safe_lwm2m_url = sanitize_request_param(lwm2m_url)
         params = {"timeRangeStart": start_time.strftime(ISO_INSTANT_FORMAT), "limit": limit}
         if end_time:
             params["timeRangeEnd"] = end_time.strftime(ISO_INSTANT_FORMAT)
