@@ -1,8 +1,7 @@
 from dataclasses import asdict
 from typing import List, Optional
-from urllib.parse import quote as sanitize_param
 
-from coiote.utils import ApiEndpoint, StringResult, api_call
+from coiote.utils import ApiEndpoint, StringResult, api_call, sanitize_request_param
 from coiote.v3.model.domains import Domain, DomainUpdateRequest
 
 
@@ -22,15 +21,15 @@ class Domains(ApiEndpoint):
 
     @api_call(Domain)
     def get_one(self, domain_id: str) -> Domain:
-        safe_domain = sanitize_param(domain_id, safe='')
+        safe_domain = sanitize_request_param(domain_id)
         return self.session.get(super()._make_url(f"/{safe_domain}"))
 
     @api_call()
     def update_one(self, domain_id: str, update: DomainUpdateRequest) -> None:
-        safe_domain = sanitize_param(domain_id, safe='')
+        safe_domain = sanitize_request_param(domain_id)
         return self.session.put(super()._make_url(f"/{safe_domain}"), json=asdict(update))
 
     @api_call()
     def delete_one(self, domain_id: str) -> None:
-        safe_domain = sanitize_param(domain_id, safe='')
-        return self.session.delete(super()._make_url(f"/{safe_domain}"))
\ No newline at end of file
+        safe_domain = sanitize_request_param(domain_id)
+        return self.session.delete(super()._make_url(f"/{safe_domain}"))
